@@ -1,7 +1,7 @@
 /*
  *  combobox.cpp  -  combo box with read-only option
  *  Program:  kalarm
- *  Copyright © 2002,2005,2007 by David Jarvie <djarvie@kde.org>
+ *  Copyright © 2002,2005,2007 David Jarvie <djarvie@kde.org>
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -25,8 +25,7 @@
 #include <QLineEdit>
 
 ComboBox::ComboBox(QWidget* parent)
-    : KComboBox(parent),
-      mReadOnly(false)
+    : KComboBox(parent)
 { }
 
 void ComboBox::setReadOnly(bool ro)
