@@ -29,7 +29,6 @@
 
 #include <kalarmcal/kaevent.h>
 
-#include <AkonadiCore/item.h>
 #include <KCalendarCore/Calendar>
 
 #include <QList>
@@ -63,7 +62,7 @@ class MainWindow : public MainWindowBase, public KCalendarCore::Calendar::Calend
         bool               isTrayParent() const;
         bool               isHiddenTrayParent() const   { return mHiddenTrayParent; }
         bool               showingArchived() const      { return mShowArchived; }
-        void               selectEvent(Akonadi::Item::Id);
+        void               selectEvent(const QString& eventId);
         KAEvent            selectedEvent() const;
         void               editAlarm(EditAlarmDlg*, const KAEvent&);
         void               clearSelection();
@@ -190,14 +189,14 @@ class MainWindow : public MainWindowBase, public KCalendarCore::Calendar::Calend
         QMenu*               mActionsMenu;
         QMenu*               mContextMenu;
         QMap<QAction*, int>  mUndoMenuIds;         // items in the undo/redo menu, in order of appearance
-        int                  mResourcesWidth;      // width of resource selector widget
-        bool                 mHiddenTrayParent;    // on session restoration, hide this window
+        int                  mResourcesWidth{-1};  // width of resource selector widget
+        bool                 mHiddenTrayParent{false}; // on session restoration, hide this window
         bool                 mShowResources;       // show resource selector
         bool                 mShowArchived;        // include archived alarms in the displayed list
-        bool                 mShown;               // true once the window has been displayed
+        bool                 mShown{false};        // true once the window has been displayed
         bool                 mActionEnableEnable;  // Enable/Disable action is set to "Enable"
         bool                 mMenuError;           // error occurred creating menus: need to show error message
-        bool                 mResizing;            // window resize is in progress
+        bool                 mResizing{false};     // window resize is in progress
 };
 
 #endif // MAINWINDOW_H
